EXPORTS
	??0RConeResourceLoader@@QAE@AAVCCoeEnv@@@Z @ 1 NONAME ; RConeResourceLoader::RConeResourceLoader(class CCoeEnv &)
	??1CCommonContentPolicy@@UAE@XZ @ 2  NONAME ; CCommonContentPolicy::~CCommonContentPolicy(void)
	??1CFindItemEngine@@UAE@XZ @ 3  NONAME ; CFindItemEngine::~CFindItemEngine(void)
	??1CTextResolver@@UAE@XZ @ 4 NONAME ; CTextResolver::~CTextResolver(void)
	?Close@RConeResourceLoader@@QAEXXZ @ 5  NONAME ; void RConeResourceLoader::Close(void)
	?DoNewSearchL@CFindItemEngine@@QAEHABVTDesC16@@W4TFindItemSearchCase@1@@Z @ 6  NONAME ; int CFindItemEngine::DoNewSearchL(class TDesC16 const &, enum TFindItemSearchCase)
	?Format@StringLoader@@SAXAAVTDes16@@ABVTDesC16@@H1@Z @ 7  NONAME ; void StringLoader::Format(class TDes16 &, class TDesC16 const &, int, class TDesC16 const &)
	?Format@StringLoader@@SAXAAVTDes16@@ABVTDesC16@@HH@Z @ 8  NONAME ; void StringLoader::Format(class TDes16 &, class TDesC16 const &, int, int)
	?IsClosedExtension@CCommonContentPolicy@@QAEHABVTDesC16@@@Z @ 9  NONAME ; int CCommonContentPolicy::IsClosedExtension(class TDesC16 const &)
	?IsClosedFileL@CCommonContentPolicy@@QAEHABVTDesC16@@@Z @ 10  NONAME ; int CCommonContentPolicy::IsClosedFileL(class TDesC16 const &)
	?IsClosedType@CCommonContentPolicy@@QAEHABVTDesC16@@@Z @ 11  NONAME ; int CCommonContentPolicy::IsClosedType(class TDesC16 const &)
	?IsDRMEnvelopeL@CCommonContentPolicy@@QAEHABVTDesC16@@@Z @ 12  NONAME ; int CCommonContentPolicy::IsDRMEnvelopeL(class TDesC16 const &)
	?IsValidPhoneNumber@CommonPhoneParser@@SAHABVTDesC16@@H@Z @ 13  NONAME ; int CommonPhoneParser::IsValidPhoneNumber(class TDesC16 const &, int)
	?Item@CFindItemEngine@@QAEHAAUSFoundItem@1@@Z @ 14  NONAME ; int CFindItemEngine::Item(struct CFindItemEngine::SFoundItem &)
	?ItemArray@CFindItemEngine@@QBEPBV?$CArrayFixFlat@USFoundItem@CFindItemEngine@@@@XZ @ 15  NONAME ; class CArrayFixFlat<struct CFindItemEngine::SFoundItem> const * CFindItemEngine::ItemArray(void) const
	?ItemCount@CFindItemEngine@@QBEHXZ @ 16  NONAME ; int CFindItemEngine::ItemCount(void) const
	?Load@StringLoader@@SAXAAVTDes16@@HPAVCCoeEnv@@@Z @ 17  NONAME ; void StringLoader::Load(class TDes16 &, int, class CCoeEnv *)
	?LoadL@StringLoader@@SAPAVHBufC16@@HABV?$CArrayFix@H@@PAVCCoeEnv@@@Z @ 18  NONAME ; class HBufC16 * StringLoader::LoadL(int, class CArrayFix<int> const &, class CCoeEnv *)
	?LoadL@StringLoader@@SAPAVHBufC16@@HABVMDesC16Array@@ABV?$CArrayFix@H@@PAVCCoeEnv@@@Z @ 19  NONAME ; class HBufC16 * StringLoader::LoadL(int, class MDesC16Array const &, class CArrayFix<int> const &, class CCoeEnv *)
	?LoadL@StringLoader@@SAPAVHBufC16@@HABVMDesC16Array@@PAVCCoeEnv@@@Z @ 20  NONAME ; class HBufC16 * StringLoader::LoadL(int, class MDesC16Array const &, class CCoeEnv *)
	?LoadL@StringLoader@@SAPAVHBufC16@@HABVTDesC16@@HPAVCCoeEnv@@@Z @ 21  NONAME ; class HBufC16 * StringLoader::LoadL(int, class TDesC16 const &, int, class CCoeEnv *)
	?LoadL@StringLoader@@SAPAVHBufC16@@HABVTDesC16@@PAVCCoeEnv@@@Z @ 22  NONAME ; class HBufC16 * StringLoader::LoadL(int, class TDesC16 const &, class CCoeEnv *)
	?LoadL@StringLoader@@SAPAVHBufC16@@HHPAVCCoeEnv@@@Z @ 23  NONAME ; class HBufC16 * StringLoader::LoadL(int, int, class CCoeEnv *)
	?LoadL@StringLoader@@SAPAVHBufC16@@HPAVCCoeEnv@@@Z @ 24  NONAME ; class HBufC16 * StringLoader::LoadL(int, class CCoeEnv *)
	?LoadLC@StringLoader@@SAPAVHBufC16@@HABV?$CArrayFix@H@@PAVCCoeEnv@@@Z @ 25  NONAME ; class HBufC16 * StringLoader::LoadLC(int, class CArrayFix<int> const &, class CCoeEnv *)
	?LoadLC@StringLoader@@SAPAVHBufC16@@HABVMDesC16Array@@ABV?$CArrayFix@H@@PAVCCoeEnv@@@Z @ 26  NONAME ; class HBufC16 * StringLoader::LoadLC(int, class MDesC16Array const &, class CArrayFix<int> const &, class CCoeEnv *)
	?LoadLC@StringLoader@@SAPAVHBufC16@@HABVMDesC16Array@@PAVCCoeEnv@@@Z @ 27  NONAME ; class HBufC16 * StringLoader::LoadLC(int, class MDesC16Array const &, class CCoeEnv *)
	?LoadLC@StringLoader@@SAPAVHBufC16@@HABVTDesC16@@HPAVCCoeEnv@@@Z @ 28  NONAME ; class HBufC16 * StringLoader::LoadLC(int, class TDesC16 const &, int, class CCoeEnv *)
	?LoadLC@StringLoader@@SAPAVHBufC16@@HABVTDesC16@@PAVCCoeEnv@@@Z @ 29  NONAME ; class HBufC16 * StringLoader::LoadLC(int, class TDesC16 const &, class CCoeEnv *)
	?LoadLC@StringLoader@@SAPAVHBufC16@@HHPAVCCoeEnv@@@Z @ 30  NONAME ; class HBufC16 * StringLoader::LoadLC(int, int, class CCoeEnv *)
	?LoadLC@StringLoader@@SAPAVHBufC16@@HPAVCCoeEnv@@@Z @ 31  NONAME ; class HBufC16 * StringLoader::LoadLC(int, class CCoeEnv *)
	?NewL@CCommonContentPolicy@@SAPAV1@XZ @ 32  NONAME ; class CCommonContentPolicy * CCommonContentPolicy::NewL(void)
	?NewL@CFindItemEngine@@SAPAV1@ABVTDesC16@@W4TFindItemSearchCase@1@@Z @ 33  NONAME ; class CFindItemEngine * CFindItemEngine::NewL(class TDesC16 const &, enum CFindItemEngine::TFindItemSearchCase)
	?NewL@CStringResourceReader@@SAPAV1@AAV?$TBuf@$0BAA@@@@Z @ 34  NONAME ; class CStringResourceReader * CStringResourceReader::NewL(class TBuf<256> &)
	?NewL@CTextResolver@@SAPAV1@AAVCCoeEnv@@@Z @ 35 NONAME ; class CTextResolver * CTextResolver::NewL(class CCoeEnv &)
	?NewL@CTextResolver@@SAPAV1@XZ @ 36 NONAME ; class CTextResolver * CTextResolver::NewL(void)
	?NewLC@CCommonContentPolicy@@SAPAV1@XZ @ 37  NONAME ; class CCommonContentPolicy * CCommonContentPolicy::NewLC(void)
	?NewLC@CStringResourceReader@@SAPAV1@AAV?$TBuf@$0BAA@@@@Z @ 38  NONAME ; class CStringResourceReader * CStringResourceReader::NewLC(class TBuf<256> &)
	?NewLC@CTextResolver@@SAPAV1@AAVCCoeEnv@@@Z @ 39 NONAME ; class CTextResolver * CTextResolver::NewLC(class CCoeEnv &)
	?NewLC@CTextResolver@@SAPAV1@XZ @ 40 NONAME ; class CTextResolver * CTextResolver::NewLC(void)
	?NextItem@CFindItemEngine@@QAEHAAUSFoundItem@1@@Z @ 41  NONAME ; int CFindItemEngine::NextItem(struct CFindItemEngine::SFoundItem &)
	?Open@RConeResourceLoader@@QAEHAAV?$TBuf@$0BAA@@@@Z @ 42  NONAME ; int RConeResourceLoader::Open(class TBuf<256> &)
	?OpenL@RConeResourceLoader@@QAEXAAV?$TBuf@$0BAA@@@@Z @ 43  NONAME ; void RConeResourceLoader::OpenL(class TBuf<256> &)
	?ParsePhoneNumber@CommonPhoneParser@@SAHAAVTDes16@@H@Z @ 44  NONAME ; int CommonPhoneParser::ParsePhoneNumber(class TDes16 &, int)
	?Position@CFindItemEngine@@QBEHXZ @ 45  NONAME ; int CFindItemEngine::Position(void) const
	?PrevItem@CFindItemEngine@@QAEHAAUSFoundItem@1@@Z @ 46  NONAME ; int CFindItemEngine::PrevItem(struct CFindItemEngine::SFoundItem &)
	?ReadResourceString@CStringResourceReader@@QAEABVTDesC16@@H@Z @ 47  NONAME ; class TDesC16 const & CStringResourceReader::ReadResourceString(int)
	?ResetPosition@CFindItemEngine@@QAEXXZ @ 48  NONAME ; void CFindItemEngine::ResetPosition(void)
	?ResolveErrorString@CTextResolver@@QAEABVTDesC16@@HAAHAAIW4TErrorContext@1@@Z @ 49 NONAME ; class TDesC16 const & CTextResolver::ResolveErrorString(int, int &, unsigned int &, enum CTextResolver::TErrorContext)
	?ResolveErrorString@CTextResolver@@QAEABVTDesC16@@HW4TErrorContext@1@@Z @ 50 NONAME ; class TDesC16 const & CTextResolver::ResolveErrorString(int, enum CTextResolver::TErrorContext)
	??0RSharedDataClient@@QAE@XZ @ 51 NONAME ABSENT ; RSharedDataClient::RSharedDataClient(void)
	?CancelFreeDiskSpaceRequest@RSharedDataClient@@QBEXXZ @ 52 NONAME ABSENT ; void RSharedDataClient::CancelFreeDiskSpaceRequest(void) const
	?Close@RSharedDataClient@@QAEXXZ @ 53 NONAME ABSENT ; void RSharedDataClient::Close(void)
	?Connect@RSharedDataClient@@QAEHXZ @ 54 NONAME ABSENT ; int RSharedDataClient::Connect(void)
	?RequestFreeDiskSpace@RSharedDataClient@@QBEXH@Z @ 55 NONAME ABSENT ; void RSharedDataClient::RequestFreeDiskSpace(int) const
	?RequestFreeDiskSpaceLC@RSharedDataClient@@QBEXH@Z @ 56 NONAME ABSENT ; void RSharedDataClient::RequestFreeDiskSpaceLC(int) const
	?ThreadStart@CSharedDataServer@@SAHAAVTSignal@1@@Z @ 57 NONAME ABSENT ; int CSharedDataServer::ThreadStart(class CSharedDataServer::TSignal &)
	?IsClosedFileL@CCommonContentPolicy@@QAEHAAVRFile@@@Z @ 58  NONAME ; int CCommonContentPolicy::IsClosedFileL(class RFile &)
	?IsDRMEnvelopeL@CCommonContentPolicy@@QAEHAAVRFile@@@Z @ 59  NONAME ; int CCommonContentPolicy::IsDRMEnvelopeL(class RFile &)
	?NewL@CStringResourceReader@@SAPAV1@AAV?$TBuf@$0BAA@@@AAVRFs@@@Z @ 60  NONAME ; class CStringResourceReader * CStringResourceReader::NewL(class TBuf<256> &, class RFs &)
	?NewLC@CStringResourceReader@@SAPAV1@AAV?$TBuf@$0BAA@@@AAVRFs@@@Z @ 61  NONAME ; class CStringResourceReader * CStringResourceReader::NewLC(class TBuf<256> &, class RFs &)
	?NewL@CCommonContentPolicy@@SAPAV1@AAVRFs@@@Z @ 62  NONAME ; class CCommonContentPolicy * CCommonContentPolicy::NewL(class RFs &)
	?NewLC@CCommonContentPolicy@@SAPAV1@AAVRFs@@@Z @ 63  NONAME ; class CCommonContentPolicy * CCommonContentPolicy::NewLC(class RFs &)
	?DoNewSearchL@CFindItemEngine@@QAEHABVTDesC16@@W4TFindItemSearchCase@1@H@Z @ 64  NONAME ; int CFindItemEngine::DoNewSearchL(class TDesC16 const &, enum CFindItemEngine::TFindItemSearchCase, int)
	?NewL@CFindItemEngine@@SAPAV1@ABVTDesC16@@W4TFindItemSearchCase@1@H@Z @ 65  NONAME ; class CFindItemEngine * CFindItemEngine::NewL(class TDesC16 const &, enum CFindItemEngine::TFindItemSearchCase, int)

